**********************************************************************************
* Script to import Mpmas output into stata
* automatically generated by mpmasql
*
* (c)  Pepijn Schreinemachers, Christian Troost, Universität Hohenheim, 2006-2012
**********************************************************************************
set more off
clear
set mem 1000M
set maxvar 5000
set more off

**********************************************************************************
* Part I: Settings
* These settings might be adapted by the user

** 1. SET THE MAIN DIRECTORY (THE VERSION FOLDER)
	global Dir "./"

** 2. DEFINE THE PREFIX OF THE OUTPUT FILES (SIMULATION RUN):
      global SUPER "examplebg_"
      global RUN "eeg09k1bs1m1dp1 eeg12k1bs1m1dp1 noeegk1bs1m1dp1"

** 3. DEFINE THE NUMBER OF PERIODS IN THE SIMULATION:
	global PERIODS "1"
	local START = 1

** 5. DEFINE ADDITIONAL PREFIX FOR COMBINED FILE
	local prescen = ""
*
********************************************************************************
* Part II: Internal settings
* The following parameters usually do not have to be changed

** 0. DEFINE THE OUTPUT FILE TYPES TO IMPORT:
	global TYPE "u p k xu xp xk"

** A. DIRECTORY WHERE THE OUTPUT FILES ARE WRITTEN:
	global T1 "Mpmas//out/"
	global OUT $Dir$T1
	cd $OUT 	/* To check whether the directory exists */

** B. DIRECTORY WHERE THE FILES WITH LABELS ARE LOCATED:
	global T2 "Mpmas//input/dat/"
	global LAB $Dir$T2
	cd $LAB 	/* To check whether the directory exists */

** SET THE DIRECTORY WHERE THE TEMPORARY (STATA) FILES ARE TO BE WRITTEN:
	global T3 "Stata/temp/"
	global TEMP $Dir$T3
	capture mkdir "$TEMP"
	cd $TEMP 	/* To check whether the directory exists */
	

** SET THE DIRECTORY WHERE THE COMBINED (STATA) FILES ARE TO BE WRITTEN:
	global T3 "Stata/combined/"
	global FULL $Dir$T4
	capture mkdir "$FULL"
	cd $FULL 	/* To check whether the directory exists */
	
*
*********************************************************************************
* Part III: The actual script
cd $TEMP
** IMPORT THE ASCII FILES AND SAVE THEM IN STATA-FORMAT:
foreach nn of global SUPER {
	foreach n0 of global RUN {		
		local n = "`nn'`n0'"
		foreach t of global TYPE {
			global PER = "0"
			local p = `START'
			while `p' <= $PERIODS {
				if `p' <  10 & `p' >=0  global PER = "0`p'"
				if `p' >= 10 global PER = "`p'"
				if `p' < 0 global PER = "`p'"
				capture quietly insheet using $OUT`n'_`t'$PER.out, tab clear nonames
				
				quietly g 		period	= $PER
				quietly g 		run		= "`n'"
				quietly save "$TEMP/temp_`n'_`t'$PER", replace
				noisily display in green "`n'_`t'$PER.out" " was imported"
				local p = `p' + 1
			}
		}

		global XU "0"
		global XP "0"
		global XK "0"

** MERGE FILES FOR ALL PERIODS TOGETHER:

		foreach t of global TYPE {
			global PER = "0"
			local i = 1
			local p = `START'

			while `p' <= $PERIODS {
				if `p' <  10 & `p' >=0  global PER = "0`p'"
				if `p' >= 10 global PER = "`p'"
				if `p' < 0 global PER = "`p'"
				** OPEN THE FIRST FILE:
				if `i' == 1 	   use "$TEMP/temp_`n'_`t'$PER", clear
				** APPEND ALL OTHER FILES:
				if `i' >  1 append using "$TEMP/temp_`n'_`t'$PER"
				local p = `p' + 1
				local i = `i' + 1
				**
				erase "$TEMP/temp_`n'_`t'$PER.dta"
			}
			order run period
			capture run $LAB`n'_`t'_labels.do
			quietly compress

			if "`t'" == "u" {
				save temp_`t', replace
				capture keep if v1 == 2 
				quietly save "$TEMP`n'_solution", replace
				use temp_`t', clear
				capture keep if v1 == 3 
				quietly save "$TEMP`n'_prices", replace
				erase "temp_`t'.dta"
			}
			else if "`t'" == "xu" {
                                quietly count
                                if r(N) > 0 {
                                        global XU "1"
                        }

				save temp_`t', replace
				capture keep if v1 == 2 
				quietly save "$TEMP`n'_Xsolution", replace
				use temp_`t', clear
				capture keep if v1 == 3 
				quietly save "$TEMP`n'_Xprices", replace
				capture erase "temp_`t'.dta"
			}
			else if "`t'" == "k" {
				save temp_`t', replace
				capture keep if v1 == 4 
				quietly save "$TEMP`n'_rhs", replace
				use temp_`t', clear
				capture	keep if v1 == 5 
				quietly save "$TEMP`n'_lhs", replace
				erase "temp_`t'.dta"
								
			}

			else if "`t'" == "xk" {
				quietly count
                                if r(N) > 0 {
                                        global XK "1"
                                }

				save temp_`t', replace
				capture keep if v1 == 4 
				quietly save "$TEMP`n'_Xrhs", replace
				use temp_`t', clear
				capture keep if v1 == 5 
				quietly save "$TEMP`n'_Xlhs", replace
				capture erase "temp_`t'.dta"
								
			}
			else if "`t'" == "xp" {
				quietly count			
				if r(N) > 0 {
					global XP "1"
				}
                              	quietly save "$TEMP`n'_Xp.dta", replace
                        }
			else {
				save temp_`t', replace
				quietly save "$TEMP`n'_`t'", replace
			}		
		}	


** MERGE SOLUTION, RHS, LHS, PERFORMANCE INTO A COMBINED FILE

		if $XP == 1 {
			use `n'_Xp.dta, clear
			gen exit = 1
			save tempXp.dta, replace
		}
		use `n'_p.dta, clear
		gen exit = 0
		if $XP == 1 {
			append using tempXp.dta
		}
		renpfix v p
		gen entry = string(p5, "%09.0f") + string(period,"%04.0f")
		save x`n'_p.dta, replace
		capture erase "tempXp.dta"
		if $XK == 1 {
			use `n'_Xrhs.dta, clear
			gen exit = 1
			save tempXrhs.dta, replace
		}
		use `n'_rhs.dta, clear
		gen exit = 0
		if $XK == 1 {
			append using tempXrhs.dta
		}
		renpfix v r
		gen entry = string(r5, "%09.0f") + string(period,"%04.0f")
		save x`n'_rhs.dta, replace
		capture erase "tempXrhs.dta"
		if $XK == 1 {		
			use `n'_Xlhs.dta, clear
			gen exit = 1
			save tempXlhs.dta, replace
		}
		use `n'_lhs.dta, clear
		gen exit = 0
		if $XK == 1 {
			append using tempXlhs.dta
		}
		renpfix v l
		gen entry = string(l5, "%09.0f") + string(period,"%04.0f")
		save x`n'_lhs.dta, replace
		capture erase "tempXlhs.dta"
		
		if $XU == 1 {	
			use `n'_Xsolution.dta, clear
			gen exit = 1
			save tempXsolution.dta, replace
		}
		use `n'_solution.dta, clear
		gen exit = 0
		if $XU == 1 {
			append using tempXsolution.dta
		}
		renpfix v u
		gen entry = string(u5, "%09.0f") + string(period,"%04.0f")
		save x`n'_solution.dta, replace
		
		joinby entry using x`n'_rhs.dta
		joinby entry using x`n'_lhs.dta
		joinby entry using x`n'_p.dta
		order entry
		save "$FULL`prescen'`n'_combined.dta", replace
		capture erase "tempXsolution.dta"

		capture run $LAB/`n'_create_animal_uvariables.do
		capture run $LAB/`n'_create_bgoption_uvariables.do
		capture run $LAB/`n'_create_biogas_uvariables.do
		capture run $LAB/`n'_create_buy_uvariables.do
		capture run $LAB/`n'_create_crop_uvariables.do
		capture run $LAB/`n'_create_cropsoil_uvariables.do
		capture run $LAB/`n'_create_cropsub_uvariables.do
		capture run $LAB/`n'_create_feed_uvariables.do
		capture run $LAB/`n'_create_harvest_buy_uvariables.do
		capture run $LAB/`n'_create_invest_uvariables.do
		capture run $LAB/`n'_create_labor_uvariables.do
		capture run $LAB/`n'_create_meka_uvariables.do
		capture run $LAB/`n'_create_rotation_uvariables.do
		capture run $LAB/`n'_create_sell_uvariables.do
		capture run $LAB/`n'_create_use_uvariables.do
		capture run $LAB/`n'_create_util_uvariables.do
		capture run $LAB/`n'_create_infra_kvariables.do
		capture run $LAB/`n'_create_labor_kvariables.do
		capture run $LAB/`n'_create_machinery_kvariables.do
		capture run $LAB/`n'_create_meka_kvariables.do
		capture run $LAB/`n'_create_soil_kvariables.do

		save "$FULL`prescen'`n'_combined.dta", replace
	}
}


** DROP THE CREATED GLOBAL MACROS:
	
	macro drop RUN PERIODS PER TYPE LAB

